==> serendipity_1.4.1.orig.tar.gz: serendipity/templates/bulletproof/lang_cz.inc.php <==
<?php # $Id: lang_cz.inc.php 1.1 2008/01/20 01:53:00 VladaAjgl $

/**
 *  @version $Revision: 1.1 $
 *  @author Vladimir Ajgl <vlada@ajgl.cz>
 *  EN-Revision: Revision of lang_en.inc.php
 *  Translated on 2007/12/07 
 *  Revision on 2008/02/28 
 */
 
 // Colorsets
@define('THEME_COLORSET',               'Barevn sada');
@define('USER_STYLESHEET',              'Pout doplujc uivatelsk soubor s css styly. Uivatel mus tento soubor run vytvoit v adresi ablony bulletproof. Tento soubor mus bt pojmenovm user.css a me bt pouit k nahrazen nkterch styl.');
// Layout
@define('LAYOUT_TYPE',                  'Uspodn blogu (B = Tlo blogu, S = Sloupec (postrann), ON = Obsah nejdve)');
@define('LAYOUT_SBS',                   'Ti sloupce, S-B-S');
@define('LAYOUT_BSS',                   'Ti sloupce, B-S-S, ON');
@define('LAYOUT_SSB',                   'Ti sloupce, S-S-B');
@define('LAYOUT_SB',                    'Dva sloupce, S-B');
@define('LAYOUT_BS',                    'Dva sloupce, B-S, ON');
@define('LAYOUT_SC',                    'Jeden sloupec, Postrann sloupec pod nm, ON');
@define('LAYOUT_SBF',                   'Dva sloupce, dva postrann sloupce - na stran a pod tlem');
@define('LAYOUT_BSF',                   'Dva sloupce, dva postrann sloupce - na stran a pod tlem, ON');
@define('JAVASCRIPT_COLUMNS',           'Vytvo stejn vysok sloupce pomoc javascriptu (trochu zpomal vykreslovn strnky).');
// Custom header
@define('BP_CUSTOM_HEADER',             'Vlastn obrzek v zhlav strnky');
@define('BP_HEADER_IMAGE',              'Vyber obrzek');
@define('BP_HEADER_TYPE',               'Opakovn obrzku v zhlav');
@define('BP_HEADER_BANNER',             'Banner (neopakovat)');
@define('BP_HEADER_HTILED',             'Vodorovn opakovan');
@define('BP_HEADER_VTILED',             'Svisle opakovan');
@define('BP_HEADER_BTILED',             'Vodorovn i svisle opakovan');
@define('BP_HEADER_POSHOR',             'Vodorovn zarovnn');
@define('BP_HEADER_POSVER',             'Svisl zarovnn');
@define('BP_CENTER',                    'na sted');
@define('BP_TOP',                       'nahoe');
@define('BP_BOTTOM',                    'dole');
// Fahrner Image Replacement
@define('FIR_BTITLE',                   'Zobrazovat nzev blogu v zhlav');
@define('FIR_BDESCR',                   'Zobrazovat popis (podnadpis) blogu v zhlav');
// Date format
@define('BP_DATE_FORMAT',               'Formt data');
// Entry footer
@define('ENTRY_FOOTER_POS',             'Umstn patiky/zhlav pspvku (takov to s informacemi o autoru, datu vydn, zaazen do kategori; rozdlen patiky = kategorie pspvku nad, zbytek pod pspvkem)');
@define('BELOW_ENTRY',                  'Patika = pod pspvkem');
@define('BELOW_TITLE',                  'Zhlav = pod nadpisem pspvku');
@define('SPLIT_FOOTER',                 'Rozdlit patiku/zhlav');
@define('FOOTER_AUTHOR',                'Zobrazit v patice autora');
@define('FOOTER_CATEGORIES',            'Zobrazit v patice kategorie');
@define('FOOTER_TIMESTAMP',             'Zobrazit v patice as zveejnn');
@define('FOOTER_COMMENTS',              'Zobrazit v patice poet koment');
@define('FOOTER_TRACKBACKS',            'Zobrazit v patice poet odezev');
@define('ALT_COMMTRACK',                'Pout alternativn zobrazen potu koment a odezev (nap. "dn komente" nebo "1 koment" msto "Koment (0)" nebo "Koment (1)")');
@define('SHOW_ADDTHIS_WIDGET',          'Zobrzit zloku AddThis (http://www.addthis.com) v patice pspvku');
@define('ADDTHIS_ACCOUNT',              'slo tu AddThis.com. Nen vyadovno, ale pokud je zadno, umon vst statistiku, jak Vs vai teni tou, jak si Vs ukldaj do zloek a jak si mezi sebou sdl obsah Vaich strnek.');
@define('SHOW_STICKY_ENTRY_FOOTER',     'Zobrazit patiku u stlch (pilepench) pspvk (vyaduje nainstalovn pluginu udlost "Rozen vlastnosti pspvk")');
@define('SHOW_STICKY_ENTRY_HEADING',    'Zobraz nadpis u stlch (pilepench) pspvk (vyaduje nainstalovn pluginu udlost "Rozen vlastnosti pspvk")');
// Page footer next page  and previous page links
@define('PREV_NEXT_STYLE',              'Zobrazit patiku "dal/pedchoz pspvek" ve tvaru');
@define('PREV_NEXT_TEXT',               'Text');
@define('PREV_NEXT_TEXT_ICON',          'Text a ikonka');
@define('PREV_NEXT_ICON',               'Ikonka');
// coComment support
@define('COCOMMENT_ACTIVE',             'Vloit coComment (http://www.cocomment.com) do formule koment');
// Counter code
@define('COUNTER_CODE',                 'Vloit kd potadla pstup a/nebo statistik webu');
@define('USE_COUNTER',                  'Pout ve zadan kd potadla/statistik?');
// Additional footer text
@define('FOOTER_TEXT',                  'Nsledujc text bude vloen do patiky pspvk');
@define('USE_FOOTER_TEXT',              'Vloit ve zadan text do patiky?');
//Sitenav
@define('SITENAV_POSITION',             'Poloha navigan lity');
@define('SITENAV_NONE',                 'dn navigan lita');
@define('SITENAV_ABOVE',                'Nad obrzkem v zhlav strnky');
@define('SITENAV_BELOW',                'Pod obrzkem v zhlav strnky');
@define('SITENAV_LEFT',                 'Na zatku LEVHO postrannho sloupce');
@define('SITENAV_RIGHT',                'Na zatku PRAVHO postrannho sloupce');
@define('SITENAV_FOOTER',               'Zobraz navigan litu v patice strnky (pokud je v pedchoz volb vybrno "dn navigan lita", nebude zobrazena nikdy bez ohledu na tuto volbu)');
@define('SITENAV_QUICKSEARCH',          'Zobrazit polko rychlho vyhledvn v navigan lit (zobrazuje se pouze v navigan lit nad nebo pod obrzkem v zhlav strnky. Je-li navigan lita v postrannch sloupcch, vyhledvac polko nen nikdy zobrazeno.)');
@define('SITENAV_TITLE',                'Nadpis pro navigan litu/menu (pouze pokud je zobrazena na zatku postrannho sloupce)');
@define('SITENAV_TITLE_TEXT',           'Hlavn menu');
@define('NAVLINK_AMOUNT',               'Zadejte poet odkaz navigan lity (ihned po zadn tto volby kliknte na "Uloi" a obnovte strnku)');
@define('NAV_LINK_TEXT',                'Test odkazu');
@define('NAV_LINK_URL',                 'URL adresa odkazu');

==> serendipity_1.5.3.orig.tar.gz: serendipity/templates/bulletproof/lang_cz.inc.php <==
<?php # lang_cz.inc.php 1.2 2009-06-30 20:21:39 VladaAjgl $

/**
 *  @version 1.2
 *  @author Vladimir Ajgl <vlada@ajgl.cz>
 *  EN-Revision: Revision of lang_en.inc.php
 *  Translated on 2007/12/07 
 *  Revision on 2008/02/28 
 *  @author Vladimr Ajgl <vlada@ajgl.cz>
 *  @revisionDate 2009/06/30
 */
 
 // Colorsets
@define('THEME_COLORSET',               'Barevn sada');
@define('USER_STYLESHEET',              'Pout doplujc uivatelsk soubor s css styly. Uivatel mus tento soubor run vytvoit v adresi ablony bulletproof. Tento soubor mus bt pojmenovm user.css a me bt pouit k nahrazen nkterch styl.');
// Layout
@define('LAYOUT_TYPE',                  'Uspodn blogu (B = Tlo blogu, S = Sloupec (postrann), ON = Obsah nejdve)');
@define('LAYOUT_SBS',                   'Ti sloupce, S-B-S');
@define('LAYOUT_BSS',                   'Ti sloupce, B-S-S, ON');
@define('LAYOUT_SSB',                   'Ti sloupce, S-S-B');
@define('LAYOUT_SB',                    'Dva sloupce, S-B');
@define('LAYOUT_BS',                    'Dva sloupce, B-S, ON');
@define('LAYOUT_SC',                    'Jeden sloupec, Postrann sloupec pod nm, ON');
@define('LAYOUT_SBF',                   'Dva sloupce, dva postrann sloupce - na stran a pod tlem');
@define('LAYOUT_BSF',                   'Dva sloupce, dva postrann sloupce - na stran a pod tlem, ON');
@define('JAVASCRIPT_COLUMNS',           'Vytvo stejn vysok sloupce pomoc javascriptu (trochu zpomal vykreslovn strnky).');
// Custom header
@define('BP_CUSTOM_HEADER',             'Vlastn obrzek v zhlav strnky');
@define('BP_HEADER_IMAGE',              'Vyber obrzek');
@define('BP_HEADER_TYPE',               'Opakovn obrzku v zhlav');
@define('BP_HEADER_BANNER',             'Banner (neopakovat)');
@define('BP_HEADER_HTILED',             'Vodorovn opakovan');
@define('BP_HEADER_VTILED',             'Svisle opakovan');
@define('BP_HEADER_BTILED',             'Vodorovn i svisle opakovan');
@define('BP_HEADER_POSHOR',             'Vodorovn zarovnn');
@define('BP_HEADER_POSVER',             'Svisl zarovnn');
@define('BP_CENTER',                    'na sted');
@define('BP_TOP',                       'nahoe');
@define('BP_BOTTOM',                    'dole');
// Fahrner Image Replacement
@define('FIR_BTITLE',                   'Zobrazovat nzev blogu v zhlav');
@define('FIR_BDESCR',                   'Zobrazovat popis (podnadpis) blogu v zhlav');
// Date format
@define('BP_DATE_FORMAT',               'Formt data');
// Entry footer
@define('ENTRY_FOOTER_POS',             'Umstn patiky/zhlav pspvku (takov to s informacemi o autoru, datu vydn, zaazen do kategori; rozdlen patiky = kategorie pspvku nad, zbytek pod pspvkem)');
@define('BELOW_ENTRY',                  'Patika = pod pspvkem');
@define('BELOW_TITLE',                  'Zhlav = pod nadpisem pspvku');
@define('SPLIT_FOOTER',                 'Rozdlit patiku/zhlav');
@define('FOOTER_AUTHOR',                'Zobrazit v patice autora');
@define('FOOTER_CATEGORIES',            'Zobrazit v patice kategorie');
@define('FOOTER_TIMESTAMP',             'Zobrazit v patice as zveejnn');
@define('FOOTER_COMMENTS',              'Zobrazit v patice poet koment');
@define('FOOTER_TRACKBACKS',            'Zobrazit v patice poet odezev');
@define('ALT_COMMTRACK',                'Pout alternativn zobrazen potu koment a odezev (nap. "dn komente" nebo "1 koment" msto "Koment (0)" nebo "Koment (1)")');
@define('SHOW_ADDTHIS_WIDGET',          'Zobrzit zloku AddThis (http://www.addthis.com) v patice pspvku');
@define('ADDTHIS_ACCOUNT',              'slo tu AddThis.com. Nen vyadovno, ale pokud je zadno, umon vst statistiku, jak Vs vai teni tou, jak si Vs ukldaj do zloek a jak si mezi sebou sdl obsah Vaich strnek.');
@define('SHOW_STICKY_ENTRY_FOOTER',     'Zobrazit patiku u stlch (pilepench) pspvk (vyaduje nainstalovn pluginu udlost "Rozen vlastnosti pspvk")');
@define('SHOW_STICKY_ENTRY_HEADING',    'Zobraz nadpis u stlch (pilepench) pspvk (vyaduje nainstalovn pluginu udlost "Rozen vlastnosti pspvk")');
// Page footer next page  and previous page links
@define('PREV_NEXT_STYLE',              'Zobrazit patiku "dal/pedchoz pspvek" ve tvaru');
@define('PREV_NEXT_TEXT',               'Text');
@define('PREV_NEXT_TEXT_ICON',          'Text a ikonka');
@define('PREV_NEXT_ICON',               'Ikonka');
// coComment support
@define('COCOMMENT_ACTIVE',             'Vloit coComment (http://www.cocomment.com) do formule koment');
// Counter code
@define('COUNTER_CODE',                 'Vloit kd potadla pstup a/nebo statistik webu');
@define('USE_COUNTER',                  'Pout ve zadan kd potadla/statistik?');
// Additional footer text
@define('FOOTER_TEXT',                  'Nsledujc text bude vloen do patiky pspvk');
@define('USE_FOOTER_TEXT',              'Vloit ve zadan text do patiky?');
//Sitenav
@define('SITENAV_POSITION',             'Poloha navigan lity');
@define('SITENAV_NONE',                 'dn navigan lita');
@define('SITENAV_ABOVE',                'Nad obrzkem v zhlav strnky');
@define('SITENAV_BELOW',                'Pod obrzkem v zhlav strnky');
@define('SITENAV_LEFT',                 'Na zatku LEVHO postrannho sloupce');
@define('SITENAV_RIGHT',                'Na zatku PRAVHO postrannho sloupce');
@define('SITENAV_FOOTER',               'Zobraz navigan litu v patice strnky (pokud je v pedchoz volb vybrno "dn navigan lita", nebude zobrazena nikdy bez ohledu na tuto volbu)');
@define('SITENAV_QUICKSEARCH',          'Zobrazit polko rychlho vyhledvn v navigan lit (zobrazuje se pouze v navigan lit nad nebo pod obrzkem v zhlav strnky. Je-li navigan lita v postrannch sloupcch, vyhledvac polko nen nikdy zobrazeno.)');
@define('SITENAV_TITLE',                'Nadpis pro navigan litu/menu (pouze pokud je zobrazena na zatku postrannho sloupce)');
@define('SITENAV_TITLE_TEXT',           'Hlavn menu');
@define('NAVLINK_AMOUNT',               'Zadejte poet odkaz navigan lity (ihned po zadn tto volby kliknte na "Uloi" a obnovte strnku)');
@define('NAV_LINK_TEXT',                'Test odkazu');
@define('NAV_LINK_URL',                 'URL adresa odkazu');

// Next lines were translated on 2009/06/30
@define('SHOW_PAGINATION',              'Zobrazovat sla strnek (strnkovn)');
